#-------------------------------------------------------------------------------
# Name:        QtEAN.pyw
# Purpose:     EAN check as website example
#
# Author:      Gerhard Röhner
#
# Created:     25.08.2022
# Copyright:   (c) 2022
# Licence:     Freeware
#-------------------------------------------------------------------------------

from PyQt6.QtWidgets import *
from PyQt6.QtGui import *
from PyQt6.QtCore import *

class Window(QMainWindow):

    def __init__(self):
        super().__init__()
        self.resize(294, 215)
        self.setWindowTitle('EAN Check')
        self.setCentralWidget(QWidget(self))
        self.create_widgets()

    def create_widgets(self):
        self.lEAN13digits = QLabel(self)
        self.lEAN13digits.setGeometry(8, 8, 80, 24)
        self.lEAN13digits.setText('EAN (13 digits)')
        self.leEAN = QLineEdit(self)
        self.leEAN.setGeometry(96, 8, 96, 24)
        self.leEAN.setText('5000112545869')
        self.bCheck = QPushButton(self)
        self.bCheck.setGeometry(200, 8, 80, 24)
        self.bCheck.setText('Check')
        self.bCheck.clicked.connect(self.bCheck_clicked)
        self.lTestresult = QLabel(self)
        self.lTestresult.setGeometry(8, 40, 80, 24)
        self.lTestresult.setText('Test result')
        self.Output = QPlainTextEdit(self)
        self.Output.setGeometry(8, 72, 280, 136)
        pass

    def output(self, line):
        self.Output.appendPlainText(line)

    def bCheck_clicked(self, checked):
        # Input
        EAN = self.leEAN.text()
        # Processing
        if not EAN.isdigit():
            self.output('An EAN must not contain any characters other than digits!')
        if len(EAN) == 13:
            self.output('Length of EAN: 13 ')
            self.output('Entered check digit: ' + EAN[12])
            sum = 0
            index = 0
            factor = 1
            while index < 12:
                sum = sum + int(EAN[index])*factor
                index = index + 1
                if factor == 1:
                    factor = 3
                else:
                    factor = 1
            if sum % 10 == 0:
                calculatedCheckDigit = 0
            else:
                calculatedCheckDigit = 10 - sum % 10
            if int(EAN[12]) == calculatedCheckDigit:
                self.output('The check digit ' + EAN[12] + ' is correct!')
            else:
                self.output('The entered check digit ' + EAN[12] + ' is incorrect!')
                self.output('The correct check digit is ' + str(calculatedCheckDigit))
        else:
            self.output('The entered EAN has ' + str(len(EAN)) + ' digits!')
            self.output('It must consist of 13 digits.')


if __name__ == "__main__":
    app = QApplication([])
    window = Window()
    window.show()
    app.exec()
